package com.goldenwater.slaj.ttsa.service;

import java.util.List;
import com.goldenwater.slaj.ttsa.domain.BisTtsaPaper;

public interface IBisTtsaPaperService {
    BisTtsaPaper selectBisTtsaPaperByGuid(String guid);
    List<BisTtsaPaper> selectBisTtsaPaperList(BisTtsaPaper bisTtsaPaper);
    int insertBisTtsaPaper(BisTtsaPaper bisTtsaPaper);
    int updateBisTtsaPaper(BisTtsaPaper bisTtsaPaper);
    int deleteBisTtsaPaperByGuid(String guid);
    int deleteBisTtsaPaperByGuids(String[] guids);
}
